@@ -36,7 +36,7 @@
  * the terms of any one of the MPL, the GPL or the LGPL.
  *
  * ***** END LICENSE BLOCK ***** */
-/* $Id: nssinit.c,v 1.69.2.3 2006/04/13 07:27:57 nelson%bolyard.com Exp $ */
+/* $Id: nssinit.c,v 1.69.2.7 2007/04/25 01:05:07 kaie%kuix.de Exp $ */
 
 #include <ctype.h>
 #include "seccomon.h"
@@ -301,14 +301,15 @@ static const char *dllname =
 /* Should we have platform ifdefs here??? */
 #define FILE_SEP '/'
 
-static void nss_FindExternalRootPaths(const char *dbpath, const char* secmodprefix,
+static void nss_FindExternalRootPaths(const char *dbpath, 
+                                      const char* secmodprefix,
                               char** retoldpath, char** retnewpath)
 {
     char *path, *oldpath = NULL, *lastsep;
     int len, path_len, secmod_len, dll_len;
 
     path_len = PORT_Strlen(dbpath);
-    secmod_len = PORT_Strlen(secmodprefix);
+    secmod_len = secmodprefix ? PORT_Strlen(secmodprefix) : 0;
     dll_len = PORT_Strlen(dllname);
     len = path_len + secmod_len + dll_len + 2; /* FILE_SEP + NULL */
 
@@ -321,7 +322,7 @@ static void nss_FindExternalRootPaths(const char *dbpath, const char* secmodpref
         path[path_len++] = FILE_SEP;
     }
     PORT_Strcpy(&path[path_len],dllname);
-    if (secmodprefix) {
+    if (secmod_len > 0) {
         lastsep = PORT_Strrchr(secmodprefix, FILE_SEP);
         if (lastsep) {
             int secmoddir_len = lastsep-secmodprefix+1; /* FILE_SEP */
@@ -429,7 +430,7 @@ nss_Init(const char *configdir, const char *certPrefix, const char *keyPrefix,
         return SECFailure;
     }
     
-    if (SECSuccess != InitOCSPGlobal()) {
+    if (SECSuccess != OCSP_InitGlobal()) {
         return SECFailure;
     }
 
@@ -682,8 +683,9 @@ NSS_RegisterShutdown(NSS_ShutdownFunc sFunc, void *appData)
 	nssShutdownList.funcs = funcs;
 	nssShutdownList.maxFuncs += NSS_SHUTDOWN_STEP;
     }
-    nssShutdownList.funcs[nssShutdownList.numFuncs++].func = sFunc;
-    nssShutdownList.funcs[nssShutdownList.numFuncs++].appData = appData;
+    nssShutdownList.funcs[nssShutdownList.numFuncs].func = sFunc;
+    nssShutdownList.funcs[nssShutdownList.numFuncs].appData = appData;
+    nssShutdownList.numFuncs++;
     PZ_Unlock(nssShutdownList.lock);
     return SECSuccess;
 }
@@ -776,11 +778,17 @@ NSS_Shutdown(void)
     SECStatus rv;
     PRStatus status;
 
+    if (!nss_IsInitted) {
+	PORT_SetError(SEC_ERROR_NOT_INITIALIZED);
+	return SECFailure;
+    }
+
     rv = nss_ShutdownShutdownList();
     if (rv != SECSuccess) {
 	shutdownRV = SECFailure;
     }
     ShutdownCRLCache();
+    OCSP_ShutdownCache();
     SECOID_Shutdown();
     status = STAN_Shutdown();
     cert_DestroySubjectKeyIDHashTable();
